@@ -865,11 +865,19 @@ void initialize(int argc, char **argv,
 			ExposureMask	/* event_mask */
 		    );
 
-	status = XSelectInput(
+	/* Make sure WindowMaker users can click happily away ... */
+	if ( withdrawn )
+		status = XSelectInput(
 			mainDisplay,	/* display    */
 			iconWindow,	/* window     */
-			ExposureMask	/* event_mask */
-	    );
+			ExposureMask | ButtonPressMask	/* event_mask */
+		    );
+	else
+		status = XSelectInput(
+				mainDisplay,	/* display    */
+				iconWindow,	/* window     */
+				ExposureMask	/* event_mask */
+		    );
 
 	/* Creating Graphics context */
 	mainGCV.foreground = fore_pix;
