@@ -1,6 +1,9 @@
 /*
- * Copyright (c) 1998  Albert Dorofeev <Albert@mail.dma.be>
- * For the updates see http://bewoner.dma.be/Albert/linux/
+ * astime is an analogue clock utility for X Windows.
+ *
+ * Copyright (c) 1998-99  Albert Dorofeev <Albert@mail.dma.be>
+ *
+ * For the updates see http://bewoner.dma.be/Albert/afterstep/
  *
  * This software is distributed under GPL. For details see LICENSE file.
  */
@@ -15,6 +18,8 @@ char *safecopy(char *dest, const char *src, unsigned short maxlen)
 {
 	/* safety precaution */
 	dest[maxlen-1] = 0;
-	return strlen(src) < maxlen ? strcpy(dest, src) : strncpy(dest, src, maxlen-1);
+	return strlen(src) < maxlen ? 
+		strcpy(dest, src) : 
+		strncpy(dest, src, maxlen-1);
 }
 
